@@ -26,6 +26,7 @@
 #include "variable.h"
 #include "apply.h"
 #include "analitzautils.h"
+#include "matrix.h"
 
 using namespace Analitza;
 
@@ -61,7 +62,7 @@ const QMap<Operator::OperatorType, QString> StringExpressionWriter::s_operators=
 
 StringExpressionWriter::StringExpressionWriter(const Object* o)
 {
-//     if (o)
+    if (o)
         m_result=o->visit(this);
 }
 
@@ -80,6 +81,16 @@ QString StringExpressionWriter::accept(const Vector* vec)
 	return QString("vector { %1 }").arg(allValues<Vector::const_iterator>(vec->constBegin(), vec->constEnd(), this).join(QString(", ")));
 }
 
+QString StringExpressionWriter::accept(const Matrix* m)
+{
+	return QString("matrix { %1 }").arg(allValues(m->constBegin(), m->constEnd(), this).join(QString(", ")));
+}
+
+QString StringExpressionWriter::accept(const MatrixRow* mr)
+{
+	return QString("matrixrow { %1 }").arg(allValues(mr->constBegin(), mr->constEnd(), this).join(QString(", ")));
+}
+
 QString StringExpressionWriter::accept(const List* vec)
 {
 	if(!vec->isEmpty() && vec->at(0)->type()==Object::value && static_cast<Cn*>(vec->at(0))->format()==Cn::Char)
